@@ -244,7 +244,7 @@ void CompressSettingPage::initUI()
     m_pCompressLevelCmb->setCurrentIndex(2);
 
     // 设置CPU线程数
-    QStringList listCpuThread = QStringList() << tr("Single thread") << tr("Multiple threads");
+    QStringList listCpuThread = QStringList() << tr("Single thread") << tr("2 threads") << tr("4 threads") << tr("8 threads");
     // 添加压缩方式
     m_pCpuCmb->addItems(listCpuThread);
 
@@ -283,7 +283,7 @@ void CompressSettingPage::initUI()
     m_pClickLbl->setLayout(pTypeLayout);
 
     QVBoxLayout *pLeftLayout = new QVBoxLayout; // 左侧整体布局
-    pLeftLayout->addSpacing(65);
+    pLeftLayout->addStretch();      // task 16309调整最小大小
     pLeftLayout->addWidget(m_pTypePixmapLbl, 0, Qt::AlignHCenter | Qt::AlignVCenter);
     pLeftLayout->addWidget(m_pClickLbl, 0, Qt::AlignHCenter | Qt::AlignVCenter);
     pLeftLayout->addStretch();
@@ -327,7 +327,7 @@ void CompressSettingPage::initUI()
     pRightWgt->setLayout(pRightLayout);
     m_pRightScroll->setFrameShape(QFrame::NoFrame);
     m_pRightScroll->setWidgetResizable(true);
-    m_pRightScroll->setMinimumHeight(345);
+    m_pRightScroll->setMinimumHeight(100);           // task 16309调整最小大小
     m_pRightScroll->setWidget(pRightWgt);
 
     // 按钮布局
@@ -738,7 +738,25 @@ void CompressSettingPage::slotCompressClicked()
     compressInfo.iVolumeSize = static_cast< int >(m_pSplitValueEdt->value() * 1024);    // 分卷大小
     compressInfo.bTar_7z = ("tar.7z" == strTmpCompresstype) ? true : false;     // 是否为tar.7z格式
     compressInfo.qSize = m_qFileSize;
-    compressInfo.iCPUTheadNum = (0 == m_pCpuCmb->currentIndex()) ? 1 : 2;        // 线程数
+
+    // 线程数
+    switch (m_pCpuCmb->currentIndex()) {
+    case 0:
+        compressInfo.iCPUTheadNum = 1;
+        break;
+    case 1:
+        compressInfo.iCPUTheadNum = 2;
+        break;
+    case 2:
+        compressInfo.iCPUTheadNum = 4;
+        break;
+    case 3:
+        compressInfo.iCPUTheadNum = 8;
+        break;
+    default:
+        compressInfo.iCPUTheadNum = 1;
+        break;
+    }
 
     // 压缩等级
     // tar、tar.Z:使用默认压缩方式
